use crate::models::work_model::WorkModel;
use crate::services::{serial_service::SerialService, sqlite_service::SqliteService, excel_service::ExcelService};


pub struct WorkService {
    serial_service: SerialService,
    sqlite_service: SqliteService,
    excel_service: ExcelService,
}

impl Default for WorkService {
    fn default() -> Self {
        todo!()
    }
}

impl WorkService {
    fn write_imei(&mut self, imei: String) -> Result<bool, String> {
        let write_imei_command = format!("AT+ECCGSN=\"IMEI\",\"{}\"", imei);
        return  self.serial_service.send_command_with_target(write_imei_command, None, "OK".to_string());
    }
    fn write_sn(&mut self, sn: String) -> Result<bool, String> {
        let write_sn_command = format!("AT+ECCGSN=\"SN\",\"{}\"", sn);
        return self.serial_service.send_command_with_target(write_sn_command, None, "OK".to_string());
    }

    fn check_imei(&mut self, imei: &str) -> Result<bool, String> {
        let check_imei_command = "AT+CGSN=1".to_string();
        return self.serial_service.send_command_with_target(check_imei_command, None, imei.to_string());
    }

    fn check_sn(&mut self, sn: &str) -> Result<bool, String> {
        let check_sn_command = "AT+CGSN=0".to_string();
        return self.serial_service.send_command_with_target(check_sn_command, None, sn.to_string());
    }
}